@@ -14,14 +14,14 @@
 PG_MODULE_MAGIC;
 
 void _PG_init(void);
-extern PGDLLEXPORT void bgw_replstatus_main(Datum d) pg_attribute_noreturn();
+extern PGDLLEXPORT void bgw_replstatus_main(Datum d);
 
 /* flags set by signal handlers */
 static volatile sig_atomic_t got_sigterm = false;
 
 /* config */
-int portnum = 5400;
-char *bindaddr = NULL;
+static int portnum = 5400;
+static char *bindaddr = NULL;
 
 /*
  * Perform a clean shutdown on SIGTERM. To do that, just
